ezhc
====

| **ezhc** stands for easy Highcharts.

| `Highcharts`_ is a popular, flexible, versatile, user friendly
  visualisation javascript library.

| Currently only `Highcharts <http://www.highcharts.com/demo>`__ and
  `Highstock`_, not `Highmap`_.


| **ezhc** is a wrapper that lets you transparently access the full
  configuration options of the library as described in their APIs,
  directly from the `Jupyter notebook`_:
| * `Highcharts <http://api.highcharts.com/highcharts>`__
| * `Highstock <http://api.highcharts.com/highstock>`__

| You just need to store the data in a `pandas`_ dataframe.
| See the examples in the `notebook`_.


.. _Highcharts: http://www.highcharts.com/
.. _Highstock: http://www.highcharts.com/stock/demo
.. _Highmap: http://www.highcharts.com/maps/demo
.. _Jupyter notebook: http://jupyter.org/
.. _pandas: http://pandas.pydata.org/
.. _notebook: http://nbviewer.ipython.org/github/oscar6echo/ezhc/blob/master/demo_ezhc.ipynb
